@@ -5,31 +5,23 @@ import pandas as pd
 from parameterized import parameterized_class
 
 from model_quality_report.quality_metrics import all_quality_metrics
-from model_quality_report.quality_report.crossvalidation_timeseries import (
-    CrossValidationTimeSeriesQualityReport,
-)
+from model_quality_report.quality_report.crossvalidation_timeseries import CrossValidationTimeSeriesQualityReport
 from model_quality_report.splitters.random import RandomDataSplitter
-from model_quality_report.splitters.temporal.cross_validation.by_frequency import (
-    ByFrequency,
-)
-from model_quality_report.splitters.temporal.cross_validation.by_horizon import (
-    ByHorizon,
-)
-from tests.models_for_tests import (
-    LinearModelWrapper,
-    LinearModelWrapperWithIndexName,
-)
+from model_quality_report.splitters.temporal.cross_validation.by_frequency import ByFrequency
+from model_quality_report.splitters.temporal.cross_validation.by_horizon import ByHorizon
+from model_quality_report.splitters.temporal.cross_validation.fixed_dates import FixedDates
+from tests.models_for_tests import LinearModelWrapper, LinearModelWrapperWithIndexName
 
 by_horizon = ByHorizon(start_split_date=pd.Timestamp("2019-01-03"), maximum_horizon=2)
-
-
 by_frequency = ByFrequency(start_split_date=pd.Timestamp("2019-01-03"), frequency="D", date_column_name="date")
+fixed_dates = FixedDates(split_dates=pd.date_range(start="2019-01-03", periods=3), date_column_name="date")
 
 
 @parameterized_class(
     [
         {"splitter": by_horizon, "len_metrics": 2},
         {"splitter": by_frequency, "len_metrics": 5},
+        {"splitter": fixed_dates, "len_metrics": 2},
     ]
 )
 class Test2DQualityReport(unittest.TestCase):
