@@ -1,19 +1,17 @@
-import os
 import unittest
+from pathlib import Path
 
 import pandas as pd
 from numpy.random import randint
 
-from model_quality_report.splitters.temporal.cross_validation.by_frequency import (
-    ByFrequency,
-)
+from model_quality_report.splitters.temporal.cross_validation.by_frequency import ByFrequency
 
 
 class TestByFrequency(unittest.TestCase):
     def setUp(self):
-        __current_dir_path = os.path.dirname(os.path.abspath(__file__))
+        data_path = Path(__file__).parent.parent.parent.parent / "data" / "date-value_df.pkl"
         test_data = (
-            pd.read_pickle(os.path.join(__current_dir_path, "../../../data/date-value_df.pkl"))
+            pd.read_pickle(data_path)
             .drop_duplicates(subset=["date"])
             .assign(date=lambda x: pd.to_datetime(x["date"]))
             .sort_values(by="date")
